@@ -1,5 +1,12 @@
+﻿from __future__ import absolute_import
+from . import core
+from .core import *
+ 
+
 """hedaro - A pentesting library for Python"""
 
 __version__ = '0.0.1'
 __author__ = 'David Rojas <david@hedaro.com>'
 __all__ = []
+
+
